@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.3.1';
+$DBIx::Squirrel::VERSION = '1.3.2';
 =pod
 
 =encoding UTF-8
@@ -13,7 +13,7 @@ DBIx::Squirrel - A C<DBI> extension
 
 =head1 VERSION
 
-version 1.3.1
+version 1.3.2
 
 =head1 SYNOPSIS
 
@@ -361,7 +361,7 @@ BEGIN {
     *DBIx::Squirrel::NORMALIZE_SQL                = *DBIx::Squirrel::util::NORMALISE_SQL;
 
     unless (defined $DBIx::Squirrel::VERSION) {
-        my $v = "1.3.0";
+        my $v = "1.3.2";
         *DBIx::Squirrel::VERSION = \$v;
     }
 }
@@ -369,26 +369,29 @@ BEGIN {
 use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
 use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
 
+# Divide the argumments into two lists:
+# 1. a list of helper function names;
+# 2. a list of names to be imported from the DBI.
 sub _partition_imports_into_helpers_and_dbi_imports {
-    my $class = shift;
     my(@helpers, @dbi);
     while (@_) {
-        my $symbol = shift;
-        next unless defined($symbol);
-        if ($symbol eq 'database_entities') {
-            my $symbols = shift;
-            if (UNIVERSAL::isa($symbols, 'ARRAY')) {
-                push @helpers, @{$symbols};
+        next unless defined($_[0]);
+        if ($_[0] =~ m/^database_entit(?:y|ies)$/i) {
+            shift;
+            if (ref($_[0])) {
+                if (UNIVERSAL::isa($_[0], 'ARRAY')) {
+                    push @helpers, @{shift()};
+                }
+                else {
+                    shift;
+                }
             }
-        }
-        elsif ($symbol eq 'database_entity') {
-            $symbol = shift;
-            if (defined($symbol) and not ref($symbol)) {
-                push @helpers, $symbol;
+            else {
+                push @helpers, shift();
             }
         }
         else {
-            push @dbi, $symbol;
+            push @dbi, shift();
         }
     }
     return (\@helpers, \@dbi);
@@ -398,7 +401,7 @@ sub import {
     no strict 'refs';    ## no critic
     my $class  = shift;
     my $caller = caller;
-    my($helpers, $dbi) = $class->_partition_imports_into_helpers_and_dbi_imports(@_);
+    my($helpers, $dbi) = _partition_imports_into_helpers_and_dbi_imports(@_);
     for my $name (@{$helpers}) {
         my $symbol = $class . '::' . $name;
         my $helper = sub {
@@ -1162,7 +1165,7 @@ It is the normalised form of the statement that is cached by the C<DBI>.
 
 =head4 C<execute> *
 
-    $rv = $sth->execute();
+    $rv = $sth->execute;
     $rv = $sth->execute(@bind_values);
     $rv = $sth->execute(\@bind_values);
     $rv = $sth->execute(%bind_mappings);
@@ -1170,7 +1173,7 @@ It is the normalised form of the statement that is cached by the C<DBI>.
 
 =head4 C<iterate>
 
-    $itor = $sth->iterate()
+    $itor = $sth->iterate
                 or die $dbh->errstr;
     $itor = $sth->iterate(@bind_values)
                 or die ...;
@@ -1193,7 +1196,7 @@ It is the normalised form of the statement that is cached by the C<DBI>.
 
 =head4 C<results>
 
-    $itor = $sth->results()
+    $itor = $sth->results
                 or die $dbh->errstr;
     $itor = $sth->results(@bind_values)
                 or die ...;
@@ -1218,8 +1221,8 @@ It is the normalised form of the statement that is cached by the C<DBI>.
 
 =head4 C<all>
 
-    @ary = $itor->all();
-    $ary_ref | undef = $itor->all();
+    @results = $itor->all;
+    $results_or_undef = $itor->all;
 
 Executes the iterator's underlying statement handle object.
 
@@ -1301,84 +1304,189 @@ The following package globals define the relevant default settings:
 
 =head4 C<count>
 
-    $count = $itor->count();
+    $count = $itor->count;
 
-Returns the number of rows fetched so far.
+Returns the total number of rows in the result set.
 
-If the iterator's statement has not yet been executed, it will be and a count
-of all rows will be returned. If the statement has been executed, and results
-have already been fetched, then only the current count is returned.
+If the iterator's statement has not yet been executed, it will be, and C<undef>
+will be returned if the statement was not executed successfully.
 
-=head4 C<count_all>
+Any results remaining to be fetched are then fetched, counted and discarded,
+and the final count is returned.
 
-    $count = $itor->count_all();
+I<B<BEWARE> that you should not use C<next> after this method has been used!>
 
-Returns the total number of rows.
+=head4 C<count_fetched>
 
-If the iterator's statement has not yet been executed, it will be. Once the
-iterator's statement has been executed, any remaining rows will be fetched,
-included in the count, and then immediately discarded.
+    $count = $itor->count_fetched;
 
-B<BEWARE> that this method will, potentially, impact any planned call to C<next>
-that didn't account for remaining rows to be fetched and discarded. Therefore,
-only use C<count_all> when you know that C<next> won't be called again.
+Returns the number of results fetched so far.
+
+If the iterator's statement has not yet been executed, it will be. Zero will
+be returned if the statement executed successfully, otherwise C<undef> is
+returned.
 
 =head4 C<execute>
 
-    $rv = $itor->execute());
+    $rv_or_undef = $itor->execute
+    $rv_or_undef = $itor->execute(@bind_values)
+    $rv_or_undef = $itor->execute(@transforms)
+    $rv_or_undef = $itor->execute(@bind_values, @transforms)
+    $rv_or_undef = $itor->execute(%bind_mappings)
+    $rv_or_undef = $itor->execute(%bind_mappings, @transforms)
+    $rv_or_undef = $itor->execute(\@bind_values)
+    $rv_or_undef = $itor->execute([@bind_values, @transforms])
+    $rv_or_undef = $itor->execute(\%bind_mappings)
+    $rv_or_undef = $itor->execute(\%bind_mappings, @transforms)
 
-Executes the iterator's underlying statemeent handle object.
+Executes the iterator's underlying statement, as well as resetting the
+iterator's internal state.
+
+When called with no arguments, any bind-values and transformations passed to
+the iterator at the time of construction will be honoured.
 
 =head4 C<first>
 
-=head4 C<iterate>
+    $result = $itor->first;
 
-    $itor | undef = $itor->iterate());
+Returns the first result in the result set, or C<undef> if there were no
+results.
 
-Executes the iterator's underlying statemeent handle object,
-returning the iterator object reference if execution was successful,
-or C<undef> if not.
+If the iterator's statement has not yet been executed, it will be, and C<undef>
+will be returned if the statement was not executed successfully.
+
+If the first result hasn't yet been fetched, it will be and the first result
+is fetched and cached. The cached value is returned.
+
+The result of the statement's execution will be returned.
+
+=head4 C<iterate> (or C<reset>)
+
+    $itor_or_undef = $itor->iterate
+    $itor_or_undef = $itor->iterate(@bind_values)
+    $itor_or_undef = $itor->iterate(@transforms)
+    $itor_or_undef = $itor->iterate(@bind_values, @transforms)
+    $itor_or_undef = $itor->iterate(%bind_mappings)
+    $itor_or_undef = $itor->iterate(%bind_mappings, @transforms)
+    $itor_or_undef = $itor->iterate(\@bind_values)
+    $itor_or_undef = $itor->iterate([@bind_values, @transforms])
+    $itor_or_undef = $itor->iterate(\%bind_mappings)
+    $itor_or_undef = $itor->iterate(\%bind_mappings, @transforms)
+
+Executes the iterator's underlying statement, as well as resetting the
+iterator's internal state.
+
+When called with no arguments, any bind-values and transformations passed to
+the iterator at the time of construction will be honoured.
+
+A reference to the iterator is returned if the statement was successfully
+executed, otherwise the method returns C<undef>.
 
 =head4 C<last>
 
+    $result = $itor->last;
+
+Returns the last result in the result set.
+
+If the iterator's statement has not yet been executed, it will be, and C<undef>
+will be returned if the statement was not executed successfully.
+
+Any results remaining to be fetched are then fetched and discarded, and the
+last result fetched is returned.
+
+I<B<BEWARE> that you should not use C<next> after this method has been used!>
+
+=head4 C<last_fetched>
+
+    $result = $itor->last_fetched;
+
+Returns the last result fetched.
+
+If the iterator's statement has not yet been executed, it will be, then
+C<undef> is returned regardless of the statement execution's outcome.
+
+If the statement was previously executed then the last result fetched is
+always cached. The cached value is returned.
+
 =head4 C<next>
 
+    $result = $itor->next;
+
+Returns the next result in the result set.
+
+If the iterator's statement has not yet been executed, it will be, and C<undef>
+will be returned if the statement was not executed successfully.
+
+There are two potential side-effects that could result from a call to C<next>:
+
+=over
+
+=item *
+
+The first time it is called, the result returned will be cached and returned in
+any subsequent call to C<first>.
+
+=item *
+
+Every time it is called, the most recent result returned will be cached and
+returned in any call to C<last_fetched>, or C<last> if it was the final result
+in the result set.
+
+=back
+
 =head4 C<one>
 
-Alias I<(see C<single>)>.
+Alias (see C<single>).
 
 =head4 C<remaining>
 
-    @ary = $itor->remaining();
-    $ary_ref | undef = $itor->remaining();
-
-When called in list-context, the C<all> method returns an array
-of all matching row objects remaining to be fetched.
-
-When called in scalar-context, this method returns a reference to
-an array of all matching row objects remaining to be fetched. Where
-no rows are matched, C<undef> would be returned.
+    @results = $itor->remaining;
+    $results_or_undef = $itor->remaining;
 
 =head4 C<reset>
 
+    $itor = $itor->reset;
+
+Executes the iterator's underlying statement handle object and resets any
+internal state.
+
+A reference to the iterator is always returned.
+
 =head4 C<rows>
 
-    $rv = $itor->rows();
+    $rows = $itor->rows;
 
 Returns the number of rows aftected by non-SELECT statements.
 
-=head4 C<single>
+=head4 C<single> (or C<one>)
+
+    $result = $itor->single;
+
+Returns the first result in the result set, or C<undef> if there were no
+results.
+
+If the iterator's statement has not yet been executed, it will be, and C<undef>
+will be returned if the statement was not executed successfully.
+
+If the first result hasn't yet been fetched, it will be and the first result
+is fetched and cached. The cached value is returned.
+
+If the result returned is one of many buffered, a warning will be issued:
+
+    Query would yield more than one result...
+
+The warning is a reminder to include a LIMIT 1 constraint in the statement.
 
 =head4 C<slice>
 
-    $slice = $itor->slice();
+    $slice = $itor->slice;
     $itor = $itor->slice($slice);
 
 May be used to determine how the iterator slices the results it fetches
 from the database. This may be an ARRAYREF or a HASHREF.
 
 To change this property, simply provide the new value as the argument. When
-used to change the buffer-size, a reference to the iterator is returned.
+used to change the slicing strategy, a reference to the iterator is returned.
 
 The following package global defines the default setting:
 
@@ -1386,7 +1494,7 @@ The following package global defines the default setting:
 
 =head4 C<slice_buffer_size>
 
-    ($slice, $buffer_size) = $itor->slice_buffer_size();
+    ($slice, $buffer_size) = $itor->slice_buffer_size;
     $itor = $itor->slice_buffer_size($slice, $buffer_size);
     $itor = $itor->slice_buffer_size($buffer_size, $slice);
 
@@ -1431,9 +1539,9 @@ The following package globals define the relevant default settings:
 
 =head4 C<sth>
 
-    $sth = $itor->sth();
+    $sth = $itor->sth;
 
-Returns the iterator's statement handle object.
+Returns the iterator's underlying statement handle object.
 
 =head1 COPYRIGHT AND LICENSE
 
